==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/PolarAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarLineSeriesBaseDescriptionMetadata } from "./PolarLineSeriesBaseDescriptionMetadata";
import { PolarAreaSeriesDescription } from "./PolarAreaSeriesDescription";
/**
 * @hidden
 */
var PolarAreaSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarAreaSeriesDescriptionMetadata, _super);
    function PolarAreaSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PolarAreaSeriesDescriptionMetadata.b = function (a) {
        if (PolarAreaSeriesDescriptionMetadata.a == null) {
            PolarAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PolarAreaSeriesDescriptionMetadata.c(PolarAreaSeriesDescriptionMetadata.a);
        }
        if (a.g(PolarAreaSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(PolarAreaSeriesDescriptionMetadata.a);
    };
    PolarAreaSeriesDescriptionMetadata.c = function (a) {
        PolarLineSeriesBaseDescriptionMetadata.c(a);
        a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
        a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
    };
    PolarAreaSeriesDescriptionMetadata.d = function (a) {
        PolarAreaSeriesDescriptionMetadata.b(a);
        a.u("PolarAreaSeries", function () { return new PolarAreaSeriesDescription(); });
        a.t("PolarAreaSeries", PolarAreaSeriesDescriptionMetadata.a);
    };
    PolarAreaSeriesDescriptionMetadata.$t = markType(PolarAreaSeriesDescriptionMetadata, 'PolarAreaSeriesDescriptionMetadata');
    PolarAreaSeriesDescriptionMetadata.a = null;
    return PolarAreaSeriesDescriptionMetadata;
}(Base));
export { PolarAreaSeriesDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/PolarAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PolarLineSeriesBaseDescriptionMetadata } from "./PolarLineSeriesBaseDescriptionMetadata";
import { PolarAreaSeriesDescription } from "./PolarAreaSeriesDescription";
/**
 * @hidden
 */
var PolarAreaSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarAreaSeriesDescriptionMetadata, _super);
    function PolarAreaSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PolarAreaSeriesDescriptionMetadata.b = function (a) {
        if (PolarAreaSeriesDescriptionMetadata.a == null) {
            PolarAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PolarAreaSeriesDescriptionMetadata.c(PolarAreaSeriesDescriptionMetadata.a);
        }
        if (a.j(PolarAreaSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(PolarAreaSeriesDescriptionMetadata.a);
    };
    PolarAreaSeriesDescriptionMetadata.c = function (a) {
        PolarLineSeriesBaseDescriptionMetadata.c(a);
        a.item("UnknownValuePlotting", "ExportedType:string:UnknownValuePlotting");
        a.item("UnknownValuePlotting@names", "LinearInterpolate;DontPlot");
    };
    PolarAreaSeriesDescriptionMetadata.d = function (a) {
        PolarAreaSeriesDescriptionMetadata.b(a);
        a.aa("PolarAreaSeries", function () { return new PolarAreaSeriesDescription(); });
        a.z("PolarAreaSeries", PolarAreaSeriesDescriptionMetadata.a);
    };
    PolarAreaSeriesDescriptionMetadata.$t = markType(PolarAreaSeriesDescriptionMetadata, 'PolarAreaSeriesDescriptionMetadata');
    PolarAreaSeriesDescriptionMetadata.a = null;
    return PolarAreaSeriesDescriptionMetadata;
}(Base));
export { PolarAreaSeriesDescriptionMetadata };
